@@ -35,6 +35,12 @@ unsafe impl<'root, T> ToOCaml<T> for OCamlRef<'root, T> {
     }
 }
 
+unsafe impl<T> ToOCaml<T> for BoxRoot<T> {
+    fn to_ocaml<'a>(&self, cr: &'a mut OCamlRuntime) -> OCaml<'a, T> {
+        self.get(cr)
+    }
+}
+
 unsafe impl ToOCaml<()> for () {
     fn to_ocaml(&self, _cr: &mut OCamlRuntime) -> OCaml<'static, ()> {
         OCaml::unit()
